summaryrefslogtreecommitdiff
path: root/src/or/or.h
diff options
context:
space:
mode:
authorRoger Dingledine <arma@torproject.org>2006-12-13 07:08:36 +0000
committerRoger Dingledine <arma@torproject.org>2006-12-13 07:08:36 +0000
commit04409f202d2f6c9ceb3619aa8f19adb013336e5f (patch)
tree34728f3cd3a772963af343159de2130608585a31 /src/or/or.h
parent2bd46cce8082246bcad43ca9a2e90bfb75bf5571 (diff)
downloadtor-04409f202d2f6c9ceb3619aa8f19adb013336e5f.tar.gz
tor-04409f202d2f6c9ceb3619aa8f19adb013336e5f.zip
reenable write limiting. nick finally convinced me this was
a smart move. more todo sub-items remain for it. svn:r9101
Diffstat (limited to 'src/or/or.h')
-rw-r--r--src/or/or.h10
1 files changed, 5 insertions, 5 deletions
diff --git a/src/or/or.h b/src/or/or.h
index 2bcc9fdca2..78355b3071 100644
--- a/src/or/or.h
+++ b/src/or/or.h
@@ -723,12 +723,12 @@ typedef struct or_connection_t {
time_t timestamp_lastempty; /**< When was the outbuf last completely empty?*/
/* bandwidth* and receiver_bucket only used by ORs in OPEN state: */
int bandwidthrate; /**< Bytes/s added to the bucket. (OPEN ORs only.) */
int bandwidthburst; /**< Max bucket size for this conn. (OPEN ORs only.) */
- int receiver_bucket; /**< When this hits 0, stop receiving. Every second we
- * add 'bandwidthrate' to this, capping it at
- * bandwidthburst. (OPEN ORs only) */
+ int read_bucket; /**< When this hits 0, stop receiving. Every second we
+ * add 'bandwidthrate' to this, capping it at
+ * bandwidthburst. (OPEN ORs only) */
circ_id_type_t circ_id_type; /**< When we send CREATE cells along this
* connection, which half of the space should
* we use? */
@@ -1968,7 +1968,7 @@ int retry_all_listeners(int force, smartlist_t *replaced_conns,
int connection_bucket_write_limit(connection_t *conn);
int global_write_bucket_empty(void);
void connection_bucket_init(void);
-void connection_bucket_refill(struct timeval *now);
+void connection_bucket_refill(int seconds_elapsed);
int connection_handle_read(connection_t *conn);
@@ -723,12 +723,12 @@ typedef struct or_connection_t {
time_t timestamp_lastempty; /**< When was the outbuf last completely empty?*/
- /* bandwidth* and receiver_bucket only used by ORs in OPEN state: */
+ /* bandwidth* and read_bucket only used by ORs in OPEN state: */
int bandwidthrate; /**< Bytes/s added to the bucket. (OPEN ORs only.) */
int bandwidthburst; /**< Max bucket size for this conn. (OPEN ORs only.) */